@@ -32,6 +32,8 @@ class Service(Enum):
 	PEDESTRIAN_DETECTION=11,
 	CROWD_COUNTING=12,
 	DRESS_INSIGHTS = 13,
+	ENSEMBLE_LICENSE_OCR=14,
+	CITY_WIDE=15,
 
 	def get_uri(self):
 		return service_uri_map.get(self, None)
@@ -51,12 +53,14 @@ service_uri_map = {
 	Service.PEDESTRIAN_DETECTION:"pedestrian-detection/",
 	Service.CROWD_COUNTING:"crowd-counting/",
 	Service.DRESS_INSIGHTS: "dress-insights/",
+	Service.ENSEMBLE_LICENSE_OCR: "ensemble-license-ocr/",
+	Service.CITY_WIDE: "city-wide/",
 
 }
 
 
 class RealTimeClient:
-	protocol = "ws://"
+	protocol = "wss://"
 	route = "ws/"
 
 	def get_or_create_eventloop(self):
@@ -191,7 +195,7 @@ class RealTimeClient:
 			await asyncio.sleep(1)
 			continue
 		try:
-			if is_connected(): 
+			if is_connected():
 			# the converted bytearray is sent using websockets
 				await self.websocket.send(array)
 			else:
@@ -238,7 +242,6 @@ class RealTimeClient:
 					print("Connection established correctly. Client Connected!")
 				# self.websocket = websocket.WebSocketApp(self.url )
 				# self.socketself.websocket.run_forever(sslopt={"cert_reqs": ssl.CERT_NONE})
-						
 				await asyncio.sleep(1)
 			except socket.gaierror:
 				print("client.py socket error!!")
