@@ -3,7 +3,8 @@ import sys
 
 sys.path.append('C:/Users/jrish/work/python-sdk/skylark_ai')
 import time
-from skylark.core.frame_process.websocket_client import Client, Service
+from skylark.core.frame_process.websocket_client import Client
+from skylark.core.clients import Service
 import logging
 import json
 import websocket
