@@ -29,7 +29,7 @@ from skylark.core.multi_stream import MultiStreamer
 
 
 # user will add authorization token here
-token = "abcd"
+token = "179961d3901780ea244d044b8fd85879589b7dcace0fb00c34e2317451a89010"
 
 # user will send fps of incoming stream, size of batch that will be formed while processing ,
 # user can continue to perform any further tasks as per need
@@ -37,19 +37,19 @@ if __name__ == '__main__':
     print('starting')
     dict = {}
     dict['id'] = 1
-    dict['service_name'] = Service.GENERAL_VIOLENCE
+    dict['service_name'] = Service.FACE_RECOG
     dict['stream_url'] = "rtsp://admin:admin123@203.134.200.170:8000/cam/realmonitor?channel=12&subtype=0"
     dict['fps'] = 15
-    dict['batch_size']=16
-    dict['sampling_rate']=4
+    dict['batch_size']=1
+    dict['sampling_rate']=1
     dict['show_processed_stream']=True
     dict['save_raw_frames'] = True
     dict['scale_percent'] = 40
     dict['quality'] = 95
-    # dict['databaseID']="2db2ae96-f341-4767-8e68-6ddd1c2f972b"
+    dict['databaseID']="2db2ae96-f341-4767-8e68-6ddd1c2f972b"
     service_details = dict
     
-    client = GeneralViolenceStreamClient(
+    client = FaceRecogStreamClient(
                 id=dict['id'],
                 stream=service_details['stream_url'],
                 fps=service_details['fps'],
@@ -60,7 +60,7 @@ if __name__ == '__main__':
                 save_raw_frames=service_details['save_raw_frames'],
                 scale_percent=service_details['scale_percent'],
                 quality=service_details['quality'],
-                # databaseID=service_details['databaseID'],
+                databaseID=service_details['databaseID'],
             )
 
 try:
